@@ -4,7 +4,9 @@ import Text.Blaze.Html5 (figure)
 import Test.Hspec
 import Text.Markdown
 import Data.Text.Lazy (Text, unpack, snoc, fromStrict)
+import qualified Data.ByteString as B
 import qualified Data.Text as T
+import Data.Text.Encoding (decodeUtf8)
 import qualified Data.Text.IO as TIO
 import qualified Data.Text.Lazy as TL
 import Text.Blaze.Html.Renderer.Text (renderHtml)
@@ -225,7 +227,7 @@ main = do
         it "inline" $ check "<p>foo<br>bar</p>" "foo<br>bar"
         it "inline xss" $ check "<p>foo<br>bar</p>" "foo<br onclick='evil'>bar"
         it "block" $ check "<div>hello world</div>" "<div>hello world</div>"
-        it "block xss" $ check "alert('evil')" "<script>alert('evil')</script>"
+        it "block xss" $ check "alert(&quot;evil&quot;)" "<script>alert(\"evil\")</script>"
         it "should be escaped" $ check "<p>1 &lt; 2</p>" "1 < 2"
         it "standalone" $ checkSet
             def { msStandaloneHtml = Set.fromList ["<hidden>", "</hidden>"], msXssProtect = False }
@@ -272,8 +274,8 @@ getExamples = do
     dir = "test/examples"
     go basename = do
         let fp = dir </> basename
-        input <- TIO.readFile fp
-        output <- TIO.readFile $ replaceExtension fp "html"
+        input <- decodeUtf8 <$> B.readFile fp
+        output <- decodeUtf8 <$> B.readFile (replaceExtension fp "html")
         let (checker, stripper)
                 | "-spec" `isInfixOf` fp = (check', dropFinalLF)
                 | otherwise = (check, T.strip)
@@ -290,6 +292,6 @@ getGruber = do
     dir = "test/Tests"
     go basename = do
         let fp = dir </> basename
-        input <- TIO.readFile fp
-        output <- TIO.readFile $ replaceExtension fp "html"
+        input <- decodeUtf8 <$> B.readFile fp
+        output <- decodeUtf8 <$> B.readFile (replaceExtension fp "html")
         return $ it basename $ checkNoNL (fromStrict $ T.strip output) (fromStrict input)
